:
# NAME:
#	set_paths - set paths
#
# SYNOPSIS:
#	/etc/set_paths [-options] "dir" ...
#
# DESCRIPTION:
#	Csh does not support functions, so this is the simplest method
#	for exporting add_path and friends to csh.  It can be used
#	from csh.login like:
#.nf
#
#	set path=(`/etc/set_paths "dir" "dir2" ...`)
#	setenv MANPATH `set_paths -P MANPATH "dir" ...`
#.fi
#
#	Options:
#
#	-P "VAR"
#		The variable to added to is "VAR", default is
#		``PATH''.
#
#	-d	Delete each "dir" from "VAR".
#
#	-p	Prepend each "dir" to "VAR", default is to append,
#		note that the last one added is at the head of the
#		list. 
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>


# RCSid:
#	$Id: set_paths.sh,v 1.2 2001/08/30 09:55:53 sjg Exp $
#
#	@(#)Copyright (c) 1991 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 

. /etc/add_path.sh

P=PATH
func=add
F=:

set -- `getopt F:P:pd $*`

while [ $# -gt 0 ]
do
	case "$1" in
	--)	shift; break;;
	-P)	P=$2; shift;;
	-p)	func=pre;;
	-d)	func=del;;
	-x)	set -x;;
	esac
	shift
done

for d in $*
do
	eval ${func}_path $d $P
done

# csh can't handle this on its own!
if [ "$SHELL" = /bin/csh -a "$P" = PATH ]; then
	eval echo \$$P | tr : ' '
else
	eval echo \$$P
fi
